api.sampledb.v1.test_helpers.sample package — Argus-Toolbelt 1.0 documentation

# api.sampledb.v1.test_helpers.sample package

## Submodules

## api.sampledb.v1.test_helpers.sample.get_evil_samples module

`api.sampledb.v1.test_helpers.sample.get_evil_samples.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/search/evil, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_evil_samples.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/search/evil, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_evil_samples.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/search/evil, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_evil_samples.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/search/evil, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sample module

`api.sampledb.v1.test_helpers.sample.get_sample.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sample.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sample.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sample.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sample_aggregated module

`api.sampledb.v1.test_helpers.sample.get_sample_aggregated.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/aggregated, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sample_aggregated.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/aggregated, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sample_aggregated.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/aggregated, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sample_aggregated.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/aggregated, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sample_children module

`api.sampledb.v1.test_helpers.sample.get_sample_children.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/children, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sample_children.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/children, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sample_children.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/children, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sample_children.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/children, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sample_download module

`api.sampledb.v1.test_helpers.sample.get_sample_download.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/download, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sample_download.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/download, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sample_download.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/download, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sample_download.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/download, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sample_tags module

`api.sampledb.v1.test_helpers.sample.get_sample_tags.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/tags, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sample_tags.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/tags, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sample_tags.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/tags, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sample_tags.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/tags, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sandbox_pcap module

`api.sampledb.v1.test_helpers.sample.get_sandbox_pcap.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/pcap, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sandbox_pcap.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/pcap, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sandbox_pcap.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/pcap, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sandbox_pcap.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/pcap, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sandbox_procgraph module

`api.sampledb.v1.test_helpers.sample.get_sandbox_procgraph.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/w+/procgraph, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sandbox_procgraph.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/w+/procgraph, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sandbox_procgraph.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/w+/procgraph, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sandbox_procgraph.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox/w+/procgraph, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.get_sandbox_runs module

`api.sampledb.v1.test_helpers.sample.get_sandbox_runs.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.get_sandbox_runs.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.get_sandbox_runs.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.get_sandbox_runs.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/sandbox, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.list_submissions_by_sample_id module

`api.sampledb.v1.test_helpers.sample.list_submissions_by_sample_id.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/submission, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.list_submissions_by_sample_id.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/submission, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.list_submissions_by_sample_id.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/submission, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.list_submissions_by_sample_id.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample/w+/submission, respond with HTTP 401

## api.sampledb.v1.test_helpers.sample.submit module

`api.sampledb.v1.test_helpers.sample.submit.` `forbidden`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample, respond with HTTP 403

`api.sampledb.v1.test_helpers.sample.submit.` `not_found`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample, respond with HTTP 404

`api.sampledb.v1.test_helpers.sample.submit.` `success`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample, respond with HTTP 200

`api.sampledb.v1.test_helpers.sample.submit.` `unauthorized`(function)

  Mock https://osl-argus-trunk-web1.mnemonic.no/web/api/sampledb/v1/sample, respond with HTTP 401

## Module contents